@@ -1,5 +1,8 @@
 import rowan
 
+# Set ROWAN_API_KEY environment variable to your API key or set rowan.api_key directly
+# rowan.api_key = "rowan-sk..."
+
 ligand = "CCC(C)(C)NC1=NCC2(CCC(=O)C2C)N1"
 
 cofolding_workflow = rowan.submit_protein_cofolding_workflow(
@@ -12,6 +15,9 @@ cofolding_workflow = rowan.submit_protein_cofolding_workflow(
     do_pose_refinement=True,
 )
 
+print(
+    f"View cofolding workflow privately at: https://labs.rowansci.com/protein-cofolding/{cofolding_workflow.uuid}"
+)
 cofolding_workflow.wait_for_result().fetch_latest(in_place=True)
 
 md_workflow = rowan.submit_pose_analysis_md_workflow(
@@ -22,6 +28,9 @@ md_workflow = rowan.submit_pose_analysis_md_workflow(
     name="Downstream molecular dynamics",
 )
 
+print(
+    f"View MD workflow privately at: https://labs.rowansci.com/pose-analysis-md/{md_workflow.uuid}"
+)
 md_workflow.wait_for_result().fetch_latest(in_place=True)
 
 # print ligand RMSD by frame
