@@ -8,9 +8,10 @@ from stjames import Molecule
 
 import rowan
 
-# rowan.api_key = ""
+# Set ROWAN_API_KEY environment variable to your API key or set rowan.api_key directly
+# rowan.api_key = "rowan-sk..."
 
-result = rowan.submit_redox_potential_workflow(
+workflow = rowan.submit_redox_potential_workflow(
     initial_molecule=Molecule.from_smiles("C1=CC=C(C=C1)C(=O)O"),
     mode="reckless",
     name="Benzoic Acid Redox Potential",
@@ -18,4 +19,6 @@ result = rowan.submit_redox_potential_workflow(
     reduction=True,
 )
 
-print(result.wait_for_result().fetch_latest(in_place=True))
+print(f"View workflow privately at: https://labs.rowansci.com/redox-potential/{workflow.uuid}")
+workflow.wait_for_result().fetch_latest(in_place=True)
+print(workflow)
