@@ -22,7 +22,7 @@ StJamesMolecule: TypeAlias = stjames.Molecule
 class Workflow(BaseModel):
     """A Rowan workflow.
 
-    Don’t instantiate this class directly. Instead use one of the submit workflow functions.
+    Don't instantiate this class directly. Instead use one of the submit workflow functions.
     Workflow data is not loaded by default to avoid unnecessary downloads that could impact
     performance. Call `load_data()` to fetch and attach the workflow data to this `Workflow` object.
 
@@ -312,11 +312,13 @@ def submit_workflow(
     if initial_smiles is not None:
         data["initial_smiles"] = initial_smiles
     elif isinstance(initial_molecule, StJamesMolecule):
-        data["initial_molecule"] = initial_molecule.model_dump()
+        data["initial_molecule"] = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, dict):
         data["initial_molecule"] = initial_molecule
     elif isinstance(initial_molecule, RdkitMol):
-        data["initial_molecule"] = StJamesMolecule.from_rdkit(initial_molecule, cid=0).model_dump()
+        data["initial_molecule"] = StJamesMolecule.from_rdkit(initial_molecule, cid=0).model_dump(
+            mode="json"
+        )
     else:
         raise ValueError("You must provide either `initial_smiles` or a valid `initial_molecule`.")
 
@@ -538,7 +540,7 @@ def submit_basic_calculation_workflow(
         tasks = ["optimize"]
 
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -560,7 +562,7 @@ def submit_basic_calculation_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "basic_calculation",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -573,7 +575,7 @@ def submit_basic_calculation_workflow(
 
 def submit_conformer_search_workflow(
     initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
-    conf_gen_mode: str = "rapid",
+    conf_gen_settings: stjames.ConformerGenSettings,
     final_method: stjames.Method | str = "aimnet2_wb97md3",
     solvent: str | None = None,
     transition_state: bool = False,
@@ -585,9 +587,7 @@ def submit_conformer_search_workflow(
     Submits a conformer search workflow to the API.
 
     :param initial_molecule: The molecule to perform the conformer search on.
-    :param conf_gen_mode: The mode to use for conformer generation. See
-    [list of available modes](https://github.com/rowansci/stjames-public/blob/master/stjames/mode.py)
-    for options.
+    :param conf_gen_settings: settings for conformer generation
     :param final_method: The method to use for the final optimization.
     See [list of available methods](https://github.com/rowansci/stjames-public/blob/master/stjames/method.py)
     for options.
@@ -601,7 +601,7 @@ def submit_conformer_search_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -629,8 +629,7 @@ def submit_conformer_search_workflow(
     workflow = stjames.ConformerSearchWorkflow(
         initial_molecule=initial_molecule,
         multistage_opt_settings=msos,
-        conf_gen_mode=conf_gen_mode,
-        mso_mode="manual",
+        conf_gen_settings=conf_gen_settings,
         solvent=solvent,
         transition_state=transition_state,
     )
@@ -639,7 +638,7 @@ def submit_conformer_search_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "conformer_search",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -690,7 +689,7 @@ def submit_solubility_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "solubility",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_smiles": initial_smiles,
         "max_credits": max_credits,
     }
@@ -762,8 +761,10 @@ def submit_pka_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "pka",
-        "workflow_data": workflow.model_dump(),
-        "initial_molecule": initial_stjames_mol.model_dump() if initial_stjames_mol else None,
+        "workflow_data": workflow.model_dump(mode="json"),
+        "initial_molecule": initial_stjames_mol.model_dump(mode="json")
+        if initial_stjames_mol
+        else None,
         "initial_smiles": initial_smiles,
         "max_credits": max_credits,
     }
@@ -799,7 +800,7 @@ def submit_redox_potential_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -814,7 +815,7 @@ def submit_redox_potential_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "redox_potential",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -848,7 +849,7 @@ def submit_fukui_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -862,9 +863,9 @@ def submit_fukui_workflow(
     )
 
     workflow_data = {
-        "opt_settings": optimization_settings.model_dump(),
+        "opt_settings": optimization_settings.model_dump(mode="json"),
         "opt_engine": stjames.Method(optimization_method).default_engine(),
-        "fukui_settings": fukui_settings.model_dump(),
+        "fukui_settings": fukui_settings.model_dump(mode="json"),
         "fukui_engine": stjames.Method(fukui_method).default_engine(),
     }
 
@@ -904,7 +905,7 @@ def submit_tautomer_search_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -917,7 +918,7 @@ def submit_tautomer_search_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "tautomers",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -945,7 +946,7 @@ def submit_descriptors_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -991,7 +992,7 @@ def submit_scan_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1018,7 +1019,7 @@ def submit_scan_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "scan",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1072,7 +1073,7 @@ def submit_macropka_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "macropka",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_smiles": initial_smiles,
         "max_credits": max_credits,
     }
@@ -1111,7 +1112,7 @@ def submit_irc_workflow(
     """
 
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1136,7 +1137,7 @@ def submit_irc_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "irc",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1193,7 +1194,7 @@ def submit_protein_cofolding_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "protein_cofolding",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "max_credits": max_credits,
     }
 
@@ -1206,7 +1207,7 @@ def submit_protein_cofolding_workflow(
 def submit_docking_workflow(
     protein: str | Protein,
     pocket: list[list[float]],
-    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol | None = None,
+    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
     executable: str = "vina",
     scoring_function: str = "vinardo",
     exhaustiveness: float = 8,
@@ -1236,7 +1237,7 @@ def submit_docking_workflow(
     """
 
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1251,7 +1252,7 @@ def submit_docking_workflow(
 
     workflow = stjames.DockingWorkflow(
         initial_molecule=initial_molecule,
-        target_uuid=protein,
+        protein=protein,
         pocket=pocket,
         do_csearch=do_csearch,
         do_optimization=do_optimization,
@@ -1263,7 +1264,7 @@ def submit_docking_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "docking",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1300,7 +1301,7 @@ def submit_ion_mobility_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1316,7 +1317,7 @@ def submit_ion_mobility_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "ion_mobility",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1350,7 +1351,7 @@ def submit_nmr_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1368,7 +1369,7 @@ def submit_nmr_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "nmr",
-        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1396,7 +1397,7 @@ def submit_strain_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
     if isinstance(initial_molecule, StJamesMolecule):
-        initial_molecule = initial_molecule.model_dump()
+        initial_molecule = initial_molecule.model_dump(mode="json")
     elif isinstance(initial_molecule, RdkitMol):
         initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0)
 
@@ -1406,7 +1407,7 @@ def submit_strain_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "strain",
-        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "initial_molecule": initial_molecule,
         "max_credits": max_credits,
     }
@@ -1454,8 +1455,10 @@ def submit_double_ended_ts_search_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "double_ended_ts_search",
-        "workflow_data": workflow.model_dump(),
-        "initial_molecule": reactant if isinstance(reactant, dict) else reactant.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
+        "initial_molecule": reactant
+        if isinstance(reactant, dict)
+        else reactant.model_dump(mode="json"),
         "max_credits": max_credits,
     }
 
@@ -1469,8 +1472,20 @@ def submit_pose_analysis_md_workflow(
     protein: str | Protein,
     initial_smiles: str,
     num_trajectories: int = 1,
-    simulation_time_ns: int = 10,
+    equilibration_time_ns: float = 1,
+    simulation_time_ns: float = 10,
+    temperature: float = 300,
+    pressure_atm: float = 1.0,
+    langevin_timescale_ps: float = 1.0,
+    timestep_fs: float = 2,
+    constrain_hydrogens: bool = True,
+    nonbonded_cutoff: float = 8.0,
+    ionic_strength_M: float = 0.10,
+    water_buffer: float = 6.0,
     ligand_residue_name: str = "LIG",
+    protein_restraint_cutoff: float | None = None,
+    protein_restraint_constant: float = 100,
+    save_solvent: bool = False,
     name: str = "Pose-Analysis MD Workflow",
     folder_uuid: str | None = None,
     max_credits: int | None = None,
@@ -1479,11 +1494,23 @@ def submit_pose_analysis_md_workflow(
     Submits a pose-analysis MD workflow to the API.
 
     :param protein: The *holo* protein on which MD will be run.
-        Can be input as a uuid or a Protein object.
+        Can be input as a UUID or a Protein object.
     :param initial_smiles: The SMILES for the ligand.
     :param num_trajectories: The number of trajectories to run.
-    :param simulation_time_ns: How long to run the simulation for, in nanoseconds.
+    :param equilibration_time_ns: how long to equilibrate trajectories for, in ns
+    :param simulation_time_ns: how long to run trajectories for, in ns
+    :param temperature: temperature, in K
+    :param pressure_atm: pressure, in atm
+    :param langevin_timescale_ps: timescale for the Langevin integrator, in ps⁻¹
+    :param timestep_fs: timestep, in femtoseconds
     :param ligand_residue_name: The name of the residue corresponding to the ligand.
+    :param constrain_hydrogens: whether or not to use SHAKE to freeze bonds to hydrogen
+    :param nonbonded_cutoff: nonbonded cutoff for particle-mesh Ewald, in Å
+    :param ionic_strength_M: ionic strength of the solution, in M (molar)
+    :param water_buffer: amount of water to add around the protein, in Å
+    :param protein_restraint_cutoff: cutoff past which alpha-carbons will be constrained, in Å
+    :param protein_restraint_constant: force constant for backbone restraints, in kcal/mol/Å²
+    :param save_solvent: whether to save solvent molecules
     :param name: The name of the workflow.
     :param folder_uuid: The UUID of the folder to place the workflow in.
     :param max_credits: The maximum number of credits to use for the workflow.
@@ -1495,18 +1522,30 @@ def submit_pose_analysis_md_workflow(
         protein = protein.uuid
 
     workflow = stjames.PoseAnalysisMolecularDynamicsWorkflow(
-        protein_uuid=protein,
+        protein=protein,
         initial_smiles=initial_smiles,
         num_trajectories=num_trajectories,
+        equilibration_time_ns=equilibration_time_ns,
         simulation_time_ns=simulation_time_ns,
+        temperature=temperature,
+        pressure_atm=pressure_atm,
+        langevin_timescale_ps=langevin_timescale_ps,
+        timestep_fs=timestep_fs,
         ligand_residue_name=ligand_residue_name,
+        constrain_hydrogens=constrain_hydrogens,
+        nonbonded_cutoff=nonbonded_cutoff,
+        ionic_strength_M=ionic_strength_M,
+        water_buffer=water_buffer,
+        protein_restraint_cutoff=protein_restraint_cutoff,
+        protein_restraint_constant=protein_restraint_constant,
+        save_solvent=save_solvent,
     )
 
     data = {
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "pose_analysis_md",
-        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "initial_smiles": initial_smiles,
         "max_credits": max_credits,
     }
@@ -1552,6 +1591,7 @@ def submit_batch_docking_workflow(
     workflow = stjames.BatchDockingWorkflow(
         initial_smiles_list=smiles_list,
         target=protein,
+        protein=protein,
         pocket=pocket,
         docking_settings=docking_settings,
     )
@@ -1560,7 +1600,7 @@ def submit_batch_docking_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "batch_docking",
-        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "max_credits": max_credits,
     }
 
@@ -1598,7 +1638,7 @@ def submit_msa_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "msa",
-        "workflow_data": workflow.model_dump(serialize_as_any=True),
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "max_credits": max_credits,
     }
 
@@ -1631,7 +1671,7 @@ def submit_admet_workflow(
         "name": name,
         "folder_uuid": folder_uuid,
         "workflow_type": "admet",
-        "workflow_data": workflow.model_dump(),
+        "workflow_data": workflow.model_dump(mode="json"),
         "initial_smiles": initial_smiles,
         "max_credits": max_credits,
     }
@@ -1643,7 +1683,8 @@ def submit_admet_workflow(
 
 
 def submit_membrane_permeability_workflow(
-    initial_smiles: str,
+    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol | str,
+    method: Literal["gnn-mtl", "pypermm"] = "gnn-mtl",
     name: str = "ADMET Workflow",
     folder_uuid: str | None = None,
     max_credits: int | None = None,
@@ -1651,7 +1692,8 @@ def submit_membrane_permeability_workflow(
     """
     Submits a membrane permeability workflow to the API.
 
-    :param initial_smiles: The molecule used in the workflow.
+    :param initial_molecule: The molecule used in the workflow.
+    :param method: The method used to compute membrane permeability.
     :param name: The name of the workflow.
     :param folder_uuid: The UUID of the folder to store the workflow in.
     :param max_credits: The maximum number of credits to use for the workflow.
@@ -1659,14 +1701,182 @@ def submit_membrane_permeability_workflow(
     :raises requests.HTTPError: if the request to the API fails.
     """
 
-    workflow = stjames.MembranePermeabilityWorkflow(initial_smiles=initial_smiles)
+    data: dict[str, Any] = {
+        "name": name,
+        "folder_uuid": folder_uuid,
+        "workflow_type": "membrane_permeability",
+        "max_credits": max_credits,
+    }
+
+    match method:
+        case "gnn-mtl":
+            assert isinstance(initial_molecule, str)
+            workflow = stjames.MembranePermeabilityWorkflow(
+                initial_smiles=initial_molecule,
+                membrane_permeability_method="chemprop_ohlsson2025",
+            )
+
+            data["initial_smiles"] = initial_molecule
+
+        case "pypermm":
+            if isinstance(initial_molecule, str):
+                raise ValueError("Cannot specify molecule as SMILES for PyPermm")
+            elif isinstance(initial_molecule, StJamesMolecule):
+                initial_molecule = initial_molecule.model_dump(mode="json")
+            elif isinstance(initial_molecule, RdkitMol):
+                initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0).model_dump(
+                    mode="json"
+                )
+
+            workflow = stjames.MembranePermeabilityWorkflow(
+                initial_molecule=initial_molecule,
+                membrane_permeability_method="pypermm",
+            )
+
+            data["initial_molecule"] = initial_molecule
+
+        case _:
+            raise ValueError(f"Unexpected {method=}")
+
+    data["workflow_data"] = workflow.model_dump(mode="json")
+
+    with api_client() as client:
+        response = client.post("/workflow", json=data)
+        response.raise_for_status()
+        return Workflow(**response.json())
+
+
+def submit_analogue_docking_workflow(
+    analogues: list[str],
+    initial_molecule: dict[str, Any] | StJamesMolecule | RdkitMol,
+    protein: str | Protein,
+    executable: str = "vina",
+    scoring_function: str = "vinardo",
+    exhaustiveness: float = 8,
+    name: str = "Analogue Docking Workflow",
+    folder_uuid: str | None = None,
+    max_credits: int | None = None,
+) -> Workflow:
+    """
+    Submits an analogue docking workflow to the API.
+
+    :param smiles_list: The SMILES strings to dock.
+    :param initial_molecule: The template to which to align molecules to.
+    :param protein: The protein to dock. Can be input as a uuid or a Protein object.
+    :param executable: Which docking implementation to use.
+    :param scoring_function: Which docking scoring function to use.
+    :param exhaustiveness: Which exhaustiveness to employ.
+    :param name: The name of the workflow.
+    :param folder_uuid: The UUID of the folder to place the workflow in.
+    :param max_credits: The maximum number of credits to use for the workflow.
+    :return: A Workflow object representing the submitted batch docking workflow.
+    :raises requests.HTTPError: if the request to the API fails.
+    """
+
+    docking_settings = {
+        "executable": executable,
+        "exhaustiveness": exhaustiveness,
+        "scoring_function": scoring_function,
+    }
+
+    if isinstance(initial_molecule, StJamesMolecule):
+        initial_molecule = initial_molecule.model_dump(mode="json")
+    elif isinstance(initial_molecule, RdkitMol):
+        initial_molecule = StJamesMolecule.from_rdkit(initial_molecule, cid=0).model_dump(
+            mode="json"
+        )
+
+    if isinstance(protein, Protein):
+        protein = protein.uuid
+
+    workflow = stjames.AnalogueDockingWorkflow(
+        analogues=analogues,
+        initial_molecule=initial_molecule,
+        protein=protein,
+        docking_settings=docking_settings,
+    )
 
     data = {
         "name": name,
         "folder_uuid": folder_uuid,
-        "workflow_type": "membrane_permeability",
-        "workflow_data": workflow.model_dump(),
-        "initial_smiles": initial_smiles,
+        "initial_molecule": initial_molecule,
+        "workflow_type": "analogue_docking",
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
+        "max_credits": max_credits,
+    }
+
+    with api_client() as client:
+        response = client.post("/workflow", json=data)
+        response.raise_for_status()
+        return Workflow(**response.json())
+
+
+def submit_protein_md_workflow(
+    protein: str | Protein,
+    num_trajectories: int = 1,
+    equilibration_time_ns: float = 1,
+    simulation_time_ns: float = 10,
+    temperature: float = 300,
+    pressure_atm: float = 1.0,
+    langevin_timescale_ps: float = 1.0,
+    timestep_fs: float = 2,
+    constrain_hydrogens: bool = True,
+    nonbonded_cutoff: float = 8.0,
+    ionic_strength_M: float = 0.10,
+    water_buffer: float = 6.0,
+    save_solvent: bool = False,
+    name: str = "Protein MD Workflow",
+    folder_uuid: str | None = None,
+    max_credits: int | None = None,
+) -> Workflow:
+    """
+    Submits a pose-analysis MD workflow to the API.
+
+    :param protein: The *holo* protein on which MD will be run.
+        Can be input as a UUID or a Protein object.
+    :param num_trajectories: The number of trajectories to run.
+    :param equilibration_time_ns: how long to equilibrate trajectories for, in ns
+    :param simulation_time_ns: how long to run trajectories for, in ns
+    :param temperature: temperature, in K
+    :param pressure_atm: pressure, in atm
+    :param langevin_timescale_ps: timescale for the Langevin integrator, in ps⁻¹
+    :param timestep_fs: timestep, in femtoseconds
+    :param constrain_hydrogens: whether or not to use SHAKE to freeze bonds to hydrogen
+    :param nonbonded_cutoff: nonbonded cutoff for particle-mesh Ewald, in Å
+    :param ionic_strength_M: ionic strength of the solution, in M (molar)
+    :param water_buffer: amount of water to add around the protein, in Å
+    :param save_solvent: whether solvent should be saed
+    :param name: The name of the workflow.
+    :param folder_uuid: The UUID of the folder to place the workflow in.
+    :param max_credits: The maximum number of credits to use for the workflow.
+    :return: A Workflow object representing the submitted workflow.
+    :raises requests.HTTPError: if the request to the API fails.
+    """
+
+    if isinstance(protein, Protein):
+        protein = protein.uuid
+
+    workflow = stjames.ProteinMolecularDynamicsWorkflow(
+        protein=protein,
+        num_trajectories=num_trajectories,
+        equilibration_time_ns=equilibration_time_ns,
+        simulation_time_ns=simulation_time_ns,
+        temperature=temperature,
+        pressure_atm=pressure_atm,
+        langevin_timescale_ps=langevin_timescale_ps,
+        timestep_fs=timestep_fs,
+        constrain_hydrogens=constrain_hydrogens,
+        nonbonded_cutoff=nonbonded_cutoff,
+        ionic_strength_M=ionic_strength_M,
+        water_buffer=water_buffer,
+        save_solvent=save_solvent,
+    )
+
+    data = {
+        "name": name,
+        "folder_uuid": folder_uuid,
+        "workflow_type": "protein_md",
+        "workflow_data": workflow.model_dump(serialize_as_any=True, mode="json"),
         "max_credits": max_credits,
     }
 
